@@ -8,7 +8,7 @@ This one uses only modules found in the standard library.
 '''
 
 __author__ = 'Miki Tebeka <miki.tebeka@gmail.com>'
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 
 from contextlib import contextmanager
 from six import b, exec_, string_types
@@ -21,6 +21,7 @@ import sys
 EOF = chr(4)
 DEFAULT_PORT = 9998
 
+
 @contextmanager
 def redirect_stdout(fo):
     old_stdout = sys.stdout
@@ -72,7 +73,6 @@ class PyHandler(socksrv.StreamRequestHandler):
                 error = format_exc()
                 self.wfile.write(b(error))
 
-
     def finish(self):
         try:
             socksrv.StreamRequestHandler.finish(self)
@@ -98,7 +98,7 @@ class ThreadedServer(socksrv.ThreadingMixIn, socksrv.TCPServer):
     allow_reuse_address = True
 
 
-def server_thread(env, port, password=None, redirect=False):
+def server_thread(env, port, password=None, redirect=False, host='localhost'):
     # Create a new handler class for this with it's own env
     class Handler(PyHandler):
         pass
@@ -106,13 +106,15 @@ def server_thread(env, port, password=None, redirect=False):
     Handler.password = password
     Handler.redirect = redirect
 
-    server = ThreadedServer(('localhost', port), Handler)
+    server = ThreadedServer((host, port), Handler)
     server.serve_forever()
 
 
-def install(env=None, port=DEFAULT_PORT, password=None, redirect=False):
+def install(env=None, port=DEFAULT_PORT, password=None, redirect=False,
+            host='localhost'):
     env = env or {}
-    t = Thread(target=server_thread, args=(env, port, password, redirect))
+    t = Thread(target=server_thread,
+               args=(env, port, password, redirect, host))
     t.daemon = True
     t.start()
 
@@ -131,10 +133,13 @@ def main(argv=None):
                         default=None)
     parser.add_argument('-r', '--redirect', help='redirect stdout',
                         default=False, action='store_true')
+    parser.add_argument('-s', '--host', help='host to bind to',
+                        default='localhost')
     args = parser.parse_args(argv[1:])
 
-    t = install(port=args.port, password=args.login, redirect=args.redirect)
-    print('Serving on port {0}'.format(args.port))
+    t = install(port=args.port, password=args.login, redirect=args.redirect,
+                host=args.host)
+    print('Serving on {0}:{1}'.format(args.host, args.port))
     t.join()
 
 
